A distributed locking implementation using Cloud Spanner. It relies on Spanner’s TrueTime and transactions support to achieve its locking mechanism. It’s a port of the original spindle, which is written in Go.
One use case for this library is leader election. If you want one host/node/pod to be the leader within a cluster/group, you can achieve that with this library. When the leader fails, it will fail over to another host/node/pod within a specific timeout.
Re-exports
pub use spindle::Lock;pub use spindle::LockBuilder;